/*
 * This file was generated by qdbusxml2cpp-fix version 0.8
 * Command line was: qdbusxml2cpp-fix -m -p display1interface /build/deepin-clipboard/src/dde-clipboard/dbus/org.deepin.dde.Display1.xml
 *
 * qdbusxml2cpp-fix is Copyright (C) 2016 Deepin Technology Co., Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef DISPLAY1INTERFACE_H
#define DISPLAY1INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <DDBusExtendedAbstractInterface>
#include <QtDBus/QtDBus>

#include "types/resolutionlist.h"
#include "types/brightnessmap.h"
#include "types/screenrect.h"
#include "types/touchscreenmap.h"
#include "types/touchscreeninfolist.h"
#include "types/touchscreeninfolist_v2.h"

/*
 * Proxy class for interface org.deepin.dde.Display1
 */
class __OrgDeepinDdeDisplay1InterfacePrivate;
class __OrgDeepinDdeDisplay1Interface : public DTK_CORE_NAMESPACE::DDBusExtendedAbstractInterface
{
    Q_OBJECT

public:
    static inline const char *staticInterfaceName()
    { return "org.deepin.dde.Display1"; }

public:
    explicit __OrgDeepinDdeDisplay1Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);

    ~__OrgDeepinDdeDisplay1Interface();

    Q_PROPERTY(BrightnessMap Brightness READ brightness NOTIFY BrightnessChanged)
    BrightnessMap brightness();

    Q_PROPERTY(int ColorTemperatureManual READ colorTemperatureManual NOTIFY ColorTemperatureManualChanged)
    int colorTemperatureManual();

    Q_PROPERTY(int ColorTemperatureMode READ colorTemperatureMode NOTIFY ColorTemperatureModeChanged)
    int colorTemperatureMode();

    Q_PROPERTY(QString CurrentCustomId READ currentCustomId NOTIFY CurrentCustomIdChanged)
    QString currentCustomId();

    Q_PROPERTY(QStringList CustomIdList READ customIdList NOTIFY CustomIdListChanged)
    QStringList customIdList();

    Q_PROPERTY(uchar DisplayMode READ displayMode NOTIFY DisplayModeChanged)
    uchar displayMode();

    Q_PROPERTY(bool HasChanged READ hasChanged NOTIFY HasChangedChanged)
    bool hasChanged();

    Q_PROPERTY(uint MaxBacklightBrightness READ maxBacklightBrightness NOTIFY MaxBacklightBrightnessChanged)
    uint maxBacklightBrightness();

    Q_PROPERTY(QList<QDBusObjectPath> Monitors READ monitors NOTIFY MonitorsChanged)
    QList<QDBusObjectPath> monitors();

    Q_PROPERTY(QString Primary READ primary NOTIFY PrimaryChanged)
    QString primary();

    Q_PROPERTY(ScreenRect PrimaryRect READ primaryRect NOTIFY PrimaryRectChanged)
    ScreenRect primaryRect();

    Q_PROPERTY(ushort ScreenHeight READ screenHeight NOTIFY ScreenHeightChanged)
    ushort screenHeight();

    Q_PROPERTY(ushort ScreenWidth READ screenWidth NOTIFY ScreenWidthChanged)
    ushort screenWidth();

    Q_PROPERTY(TouchscreenMap TouchMap READ touchMap NOTIFY TouchMapChanged)
    TouchscreenMap touchMap();

    Q_PROPERTY(TouchscreenInfoList Touchscreens READ touchscreens NOTIFY TouchscreensChanged)
    TouchscreenInfoList touchscreens();

    Q_PROPERTY(TouchscreenInfoList_V2 TouchscreensV2 READ touchscreensV2 NOTIFY TouchscreensV2Changed)
    TouchscreenInfoList_V2 touchscreensV2();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> ApplyChanges()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ApplyChanges"), argumentList);
    }

    inline void ApplyChangesQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("ApplyChanges"), argumentList);
    }


    inline QDBusPendingReply<> AssociateTouch(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("AssociateTouch"), argumentList);
    }

    inline void AssociateTouchQueued(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("AssociateTouch"), argumentList);
    }


    inline QDBusPendingReply<> AssociateTouchByUUID(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("AssociateTouchByUUID"), argumentList);
    }

    inline void AssociateTouchByUUIDQueued(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("AssociateTouchByUUID"), argumentList);
    }


    inline QDBusPendingReply<> ChangeBrightness(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("ChangeBrightness"), argumentList);
    }

    inline void ChangeBrightnessQueued(bool in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("ChangeBrightness"), argumentList);
    }


    inline QDBusPendingReply<> DeleteCustomMode(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("DeleteCustomMode"), argumentList);
    }

    inline void DeleteCustomModeQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("DeleteCustomMode"), argumentList);
    }


    inline QDBusPendingReply<uchar> GetRealDisplayMode()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetRealDisplayMode"), argumentList);
    }



    inline QDBusPendingReply<QStringList> ListOutputNames()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ListOutputNames"), argumentList);
    }



    inline QDBusPendingReply<ResolutionList> ListOutputsCommonModes()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ListOutputsCommonModes"), argumentList);
    }



    inline QDBusPendingReply<> ModifyConfigName(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("ModifyConfigName"), argumentList);
    }

    inline void ModifyConfigNameQueued(const QString &in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("ModifyConfigName"), argumentList);
    }


    inline QDBusPendingReply<> RefreshBrightness()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("RefreshBrightness"), argumentList);
    }

    inline void RefreshBrightnessQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("RefreshBrightness"), argumentList);
    }


    inline QDBusPendingReply<> Reset()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Reset"), argumentList);
    }

    inline void ResetQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Reset"), argumentList);
    }


    inline QDBusPendingReply<> ResetChanges()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ResetChanges"), argumentList);
    }

    inline void ResetChangesQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("ResetChanges"), argumentList);
    }


    inline QDBusPendingReply<> Save()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("Save"), argumentList);
    }

    inline void SaveQueued()
    {
        QList<QVariant> argumentList;

        CallQueued(QStringLiteral("Save"), argumentList);
    }


    inline QDBusPendingReply<> SetAndSaveBrightness(const QString &in0, double in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetAndSaveBrightness"), argumentList);
    }

    inline void SetAndSaveBrightnessQueued(const QString &in0, double in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetAndSaveBrightness"), argumentList);
    }


    inline QDBusPendingReply<> SetBrightness(const QString &in0, double in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SetBrightness"), argumentList);
    }

    inline void SetBrightnessQueued(const QString &in0, double in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SetBrightness"), argumentList);
    }


    inline QDBusPendingReply<> SetColorTemperature(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetColorTemperature"), argumentList);
    }

    inline void SetColorTemperatureQueued(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetColorTemperature"), argumentList);
    }


    inline QDBusPendingReply<> SetMethodAdjustCCT(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetMethodAdjustCCT"), argumentList);
    }

    inline void SetMethodAdjustCCTQueued(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetMethodAdjustCCT"), argumentList);
    }


    inline QDBusPendingReply<> SetPrimary(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("SetPrimary"), argumentList);
    }

    inline void SetPrimaryQueued(const QString &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);

        CallQueued(QStringLiteral("SetPrimary"), argumentList);
    }


    inline QDBusPendingReply<> SwitchMode(uchar in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);
        return asyncCallWithArgumentList(QStringLiteral("SwitchMode"), argumentList);
    }

    inline void SwitchModeQueued(uchar in0, const QString &in1)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0) << QVariant::fromValue(in1);

        CallQueued(QStringLiteral("SwitchMode"), argumentList);
    }



Q_SIGNALS: // SIGNALS
    // begin property changed signals
    void BrightnessChanged(BrightnessMap  value) const;
    void ColorTemperatureManualChanged(int  value) const;
    void ColorTemperatureModeChanged(int  value) const;
    void CurrentCustomIdChanged(const QString & value) const;
    void CustomIdListChanged(const QStringList & value) const;
    void DisplayModeChanged(uchar  value) const;
    void HasChangedChanged(bool  value) const;
    void MaxBacklightBrightnessChanged(uint  value) const;
    void MonitorsChanged(const QList<QDBusObjectPath> & value) const;
    void PrimaryChanged(const QString & value) const;
    void PrimaryRectChanged(ScreenRect  value) const;
    void ScreenHeightChanged(ushort  value) const;
    void ScreenWidthChanged(ushort  value) const;
    void TouchMapChanged(TouchscreenMap  value) const;
    void TouchscreensChanged(TouchscreenInfoList  value) const;
    void TouchscreensV2Changed(TouchscreenInfoList_V2  value) const;

public Q_SLOTS:
    void CallQueued(const QString &callName, const QList<QVariant> &args);

private Q_SLOTS:
    void onPendingCallFinished(QDBusPendingCallWatcher *w);
    void onPropertyChanged(const QString &propName, const QVariant &value);

private:
    __OrgDeepinDdeDisplay1InterfacePrivate *d_ptr;
};

namespace org {
  namespace deepin {
    namespace dde {
      typedef ::__OrgDeepinDdeDisplay1Interface Display1;
    }
  }
}
#endif
