/****************************************************************************
** Meta object code from reading C++ file 'dock1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dock1interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dock1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgDeepinDdeDaemonDock1Interface::qt_create_metaobjectdata<qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgDeepinDdeDaemonDock1Interface",
        "DisplayModeChanged",
        "",
        "displaymode",
        "FrontendWindowRectChanged",
        "QRect",
        "FrontendWindowRect",
        "HideModeChanged",
        "hideMode",
        "HideStateChanged",
        "hideState",
        "PositionChanged",
        "Position",
        "WindowSizeEfficientChanged",
        "size",
        "WindowSizeFashionChanged",
        "IsDocked",
        "QDBusPendingReply<bool>",
        "desktopFile",
        "RequestDock",
        "index",
        "RequestUndock",
        "DisplayMode",
        "HideMode",
        "HideState",
        "WindowSizeEfficient",
        "WindowSizeFashion"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'FrontendWindowRectChanged'
        QtMocHelpers::SignalData<void(const QRect &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'HideModeChanged'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'HideStateChanged'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'PositionChanged'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'WindowSizeEfficientChanged'
        QtMocHelpers::SignalData<void(uint)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Signal 'WindowSizeFashionChanged'
        QtMocHelpers::SignalData<void(uint)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Slot 'IsDocked'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'RequestDock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, int)>(19, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'RequestUndock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'FrontendWindowRect'
        QtMocHelpers::PropertyData<QRect>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'HideMode'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'HideState'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'Position'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WindowSizeEfficient'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WindowSizeFashion'
        QtMocHelpers::PropertyData<uint>(26, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgDeepinDdeDaemonDock1Interface, qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgDeepinDdeDaemonDock1Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t>.metaTypes,
    nullptr
} };

void OrgDeepinDdeDaemonDock1Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgDeepinDdeDaemonDock1Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DisplayModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->FrontendWindowRectChanged((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 2: _t->HideModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->HideStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->PositionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->WindowSizeEfficientChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->WindowSizeFashionChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 7: { QDBusPendingReply<bool> _r = _t->IsDocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->RequestDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<bool> _r = _t->RequestUndock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(int )>(_a, &OrgDeepinDdeDaemonDock1Interface::DisplayModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(const QRect & )>(_a, &OrgDeepinDdeDaemonDock1Interface::FrontendWindowRectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(int )>(_a, &OrgDeepinDdeDaemonDock1Interface::HideModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(int )>(_a, &OrgDeepinDdeDaemonDock1Interface::HideStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(int )>(_a, &OrgDeepinDdeDaemonDock1Interface::PositionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(uint )>(_a, &OrgDeepinDdeDaemonDock1Interface::WindowSizeEfficientChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinDdeDaemonDock1Interface::*)(uint )>(_a, &OrgDeepinDdeDaemonDock1Interface::WindowSizeFashionChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->displayMode(); break;
        case 1: *reinterpret_cast<QRect*>(_v) = _t->frontendWindowRect(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->hideMode(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->hideState(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->position(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->windowSizeEfficient(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->windowSizeFashion(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDisplayMode(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setHideMode(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setWindowSizeEfficient(*reinterpret_cast<uint*>(_v)); break;
        case 6: _t->setWindowSizeFashion(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgDeepinDdeDaemonDock1Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgDeepinDdeDaemonDock1Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32OrgDeepinDdeDaemonDock1InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgDeepinDdeDaemonDock1Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OrgDeepinDdeDaemonDock1Interface::DisplayModeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgDeepinDdeDaemonDock1Interface::FrontendWindowRectChanged(const QRect & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgDeepinDdeDaemonDock1Interface::HideModeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgDeepinDdeDaemonDock1Interface::HideStateChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgDeepinDdeDaemonDock1Interface::PositionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgDeepinDdeDaemonDock1Interface::WindowSizeEfficientChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgDeepinDdeDaemonDock1Interface::WindowSizeFashionChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
