// This file is autogenerated. Changes will be overwritten.
#include "Z4Y4DHTLQK/moc_clipboarddaemon.cpp"
#include "Z4Y4DHTLQK/moc_clipboardloader.cpp"
#include "JOY6TXXXYK/moc_dwaylandmimedata.cpp"
#include "JOY6TXXXYK/moc_wlrdatacontrolclipboardinterface.cpp"
#include "JOY6TXXXYK/moc_wlrdatacontroldeviceintegration.cpp"
#include "JOY6TXXXYK/moc_wlrdatacontrolmanagerintegration.cpp"
#include "JOY6TXXXYK/moc_wlrdatacontrolofferintegration.cpp"
#include "JOY6TXXXYK/moc_wlrdatacontrolsourceintegration.cpp"
