/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.Clipboard1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef CLIPBOARD1ADAPTOR_H
#define CLIPBOARD1ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "mainwindow.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.deepin.dde.Clipboard1
 */
class Clipboard1Adaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.deepin.dde.Clipboard1")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.deepin.dde.Clipboard1\">\n"
"    <method name=\"Toggle\"/>\n"
"    <method name=\"Show\"/>\n"
"    <method name=\"Hide\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"clipboardVisible\"/>\n"
"    <signal name=\"clipboardVisibleChanged\">\n"
"      <arg type=\"b\" name=\"visible\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    Clipboard1Adaptor(MainWindow *parent);
    ~Clipboard1Adaptor() override;

    inline MainWindow *parent() const
    { return static_cast<MainWindow *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(bool clipboardVisible READ clipboardVisible)
    bool clipboardVisible() const;

public Q_SLOTS: // METHODS
    void Hide();
    void Show();
    void Toggle();
Q_SIGNALS: // SIGNALS
    void clipboardVisibleChanged(bool visible);
};

#endif
